## XGAE: Extreme General Agent Engine 
### Functional Features
- Support Custom prompt and external MCP Tools
- Support Langfuse
- Support Langgraph
- Support GAIA2 ARE agent and Custom MCP Apps
- Support Human-in-Loop in agent
- Can Use A2A protocol call A2A Agent as tool by 'xgaproxy' project
- Can Use E2B or Daytona Sandbox of 'xgatools' project

### Non-Functional Features
- Faster than SUNA Engine's speed
- Architecture is lighter than SUNA Engine
- Separate tools from Agent Engine

### Examples
- langgraph:  Build React mode Langgraph Agent by XGA Engine
- are: Build GAIA2 ARE Agent by XGA Engine
- engine: Use XGA Engine in various scenarios
- tools: Simulation tools for example and test